clear all;
global l B I_supp forces_ext rho E A_underline A_overline M mu m n_s nodes index_nodes_connected



%% Construct truss example id = 1,...,4
id = 4;
[nodes, ...
 index_nodes_fixed, ...
 index_nodes_connected, ...
 l, ...
 B, ...
 I_supp, ...
 forces_ext, ...
 m, ...
 n, ...
 n_s ...
 ] = trussType(id);

% Example settings
switch id
    case 1
        rho         = 1 * ones(m, 1);
        E           = 1 * ones(m, 1);
        A_underline = 1e-4 * ones(m, 1);
        A_overline  = 1 * ones(m, 1);
        M           = 10;
        mu          = 1e-4;
        
        A = 0.001 * ones(m, 1);
        q = -0.0001 * ones(m, 1);
        forces_supp = 0 * ones(3 * n_s, 1);
        x0 = [A; q; forces_supp];
        lambda0 = 0 * ones(3 * n, 1);
        
        % The optimal solution we obtained
        x_solution = importdata('truss1_sol.mat');
    case 2
        rho         = 1 * ones(m, 1);
        E           = 1 * ones(m, 1);
        A_underline = 1e-4 * ones(m, 1);
        A_overline  = 1 * ones(m, 1);
        M           = 10;
        mu          = 1e-4;
        
        A = 0.001 * ones(m, 1);
        q = -0.0001 * ones(m, 1);
        forces_supp = 0 * ones(3 * n_s, 1);
        x0 = [A; q; forces_supp];
        lambda0 = 0 * ones(3 * n, 1);
        
        x_solution = zeros(length(x0),1);
    case 3
        rho         = 1 * ones(m, 1);
        E           = 1 * ones(m, 1);
        A_underline = 1e-4 * ones(m, 1);
        A_overline  = 1 * ones(m, 1);
        M           = 10;
        mu          = 1e-4;
        
        A = 0.001 * ones(m, 1);
        q = -0.0001 * ones(m, 1);
        forces_supp = 0 * ones(3 * n_s, 1);
        x0 = [A; q; forces_supp];
        lambda0 = 0 * ones(3 * n, 1);
        
        x_solution = zeros(length(x0),1);
    case 4
        rho         = 1 * ones(m, 1);
        E           = 1 * ones(m, 1);
        A_underline = 1e-3 * ones(m, 1);
        A_overline  = 1.2 * ones(m, 1);
        M           = 45;
        mu          = 1e-4;
        
        A = 0.003 * ones(m, 1);
        q = -0.0001 * ones(m, 1);
        forces_supp = 0 * ones(3 * n_s, 1);
        x0 = [A; q; forces_supp];
        
        x_solution = zeros(length(x0),1);
end

%% SQP Algorithm settings
max_iterations = 100;
tolerance = 1e-8;

eta = .4;
tau = 1;

% Check if initial point is feasible.
% min(constraintsInequality(x0))

% Run SQP Algorithm
[x, errors] = linesearchSQP(@objectiveFunction, ...
                            @objectiveGradient, ...
                            @constraintsEquality, ...
                            [spalloc(3 * n, m, 0) B -I_supp], ...
                            @constraintsInequality, ...
                            @lagrangianHessian, ...
                            x0, ...
                            lambda0, ...
                            eta, ...
                            tau, ...
                            max_iterations, ...
                            tolerance, ...
                            x_solution);
             
%% Plot results.

% Plotting the errors for id = 1.
%trussPlot(nodes, index_nodes_connected, m, x(1:m));

% set(gca, 'Color', 'none');
%     t = 1:length(errors);
%     plot(log(errors));
%     hold on
%     plot(-3*t +35,'r')
%     xlabel('Iteration $k$','Interpreter','LaTex', 'Fontsize', 20);
%     ylabel('$\log(||x_k - x^{\star}||_2)$','Interpreter','LaTex', 'Fontsize', 20);
%     legend('numerical','cubic')
    
% Storing the result:
%     addpath tools/export_fig/
%     export_fig ../gfx/order -pdf -transparent
    


