function [nodes, ...                    % 3D nodes columnvise
          index_nodes_fixed, ...        % List of column indices of nodes
          index_nodes_connected, ...    % List of column indices of nodes
          l, ...                        %
          B, ...                        %
          I_supp, ...                   %
          forces_ext, ...               %
          m, ...                        %
          n, ...                        %
          n_s ...                       %
          ] = trussType(id)
      
    %% Set up test examples
    switch id
        case 1
            %% Tower
            % Nodes
            n = 13;
            nodes = zeros(3, n);
            i = 1;
            for x = 0:1
                for y = 0:1
                    for z = 0:2
                        nodes(:, i) = [x; y; z];
                        i = i + 1;
                    end
                end
            end
            nodes(:, n) = [.5; .5; 2.5];

            % Fixed nodes
            [~, index_nodes_fixed] = find(nodes(3, :) == 0);

            % Prescribed external forces
            index_nodes_free = setdiff(1:n, index_nodes_fixed);
            index_nodes_free_nonzero_forces = intersect(n, index_nodes_free);
            forces_ext = zeros(3, n);
            forces_ext(:, index_nodes_free_nonzero_forces) = [0; 0; -1];

        case 2
            %% Cantilever
            % Nodes
            n = 13;
            nodes = zeros(3, n);
            i = 1;
            for x = 0:1
                for y = 0:1
                    for z = 0:2
                        nodes(:, i) = [x; y; z];
                        i = i + 1;
                    end
                end
            end
            nodes(:, n) = [.5; .5; 2.5];

            % Fixed nodes
            [~, index_nodes_fixed] = find(nodes(3, :) == 0);

            % Prescribed external forces
            index_nodes_free = setdiff(1:n, index_nodes_fixed);
            index_nodes_free_nonzero_forces = intersect(n, index_nodes_free);
            forces_ext = zeros(3, n);
            forces_ext(:, index_nodes_free_nonzero_forces) = [1; 0; 0];

        case 3
            %% Bridge
            % Nodes
            n = 20;
            nodes = zeros(3, n);
            i = 1;
            for x = 0:4
                for y = 0:1
                    for z = 0:1
                        nodes(:, i) = [x; y; z];
                        i = i + 1;
                    end
                end
            end

            % Fixed nodes
            [~, index_nodes_fixed] = find((nodes(1, :) == 0 | nodes(1, :) == 4) & nodes(3, :) == 0);
            
            % Prescribed external forces
            index_nodes_free = setdiff(1:n, index_nodes_fixed);
            index_nodes_free_nonzero_forces = intersect(find(nodes(3, :) == 0), index_nodes_free);
            forces_ext = zeros(3, n);
            forces_ext(:, index_nodes_free_nonzero_forces) = repmat([0; 0; -1], 1, length(index_nodes_free_nonzero_forces));
        
        case 4
            %% (Extended) Crane example
            
            height = 13;
            rear = 3;
            front = 8;
            seq = [-rear:-1 2:front];
            %%%%
            % Nodes
            n = 4*(height+1) + 4*length(seq) + 1;
            nodes = zeros(3, n);
            i = 1;
            % Building the crane base
            for x = 0:1
                for y = 0:1
                    for z = 0:height
                        nodes(:, i) = [x; y; z];
                        i = i + 1;
                    end
                end
            end
            weight_indexes = zeros(1,4);
            weigth_ind_conuter = 1;
            for x = seq
                for y = 0:1
                    for z = height-4:height-3
                        nodes(:, i) = [x; y; z];
                        if (x <= -rear+1) && (z == height-4)
                            weight_indexes(weigth_ind_conuter) = i;
                            weigth_ind_conuter = weigth_ind_conuter + 1;
                        end
                        i = i + 1;
                    end
                end
            end
            nodes(:,n) = [front-0.5;0.5;height-5];
            % Fixed nodes
            [~, index_nodes_fixed] = find(nodes(3, :) == 0);

            % Prescribed external forces
            index_nodes_free = setdiff(1:n, index_nodes_fixed);
            index_nodes_free_nonzero_forces = intersect(n, index_nodes_free);
            forces_ext = zeros(3, n);
            forces_ext(:, index_nodes_free_nonzero_forces) = [0; 0; -5];
            forces_ext(:, weight_indexes) = repmat([0; 0; -3] , 1,length(weight_indexes));
            

            
    end
        
    %% Connected nodes and bar lengths
    total_possible_no_of_bars = n * (n - 1) / 2;
    index_nodes_connected = zeros(total_possible_no_of_bars, 2);
    l = zeros(total_possible_no_of_bars, 1);
    
%     if id <= 3 || id == 5
        dist = (id<4)*sqrt(3) + (id>=4)*sqrt(2);    %%%%
        k = 1;
        for i = 1:n-1
            for j = i+1:n
                node_distance = norm(nodes(:, j) - nodes(:, i));
                if id == 4
                    bool = ((nodes(3,i)==height || nodes(3,j)==height) && abs(node_distance - sqrt(18)) < 1e-8);
                else
                    bool = 0;
                end
                if node_distance <= dist || bool   %%%%
                    index_nodes_connected(k, :) = [i j];
                    l(k) = node_distance;
                    k = k + 1;
                end
            end
        end
        m = k - 1;

        index_nodes_connected = index_nodes_connected(1:m, :);
        l = l(1:m);
    
    %% Construction of B matrix
    B = zeros(3 * n, m);
    for i = 1:n
        B_row_index = 3 * (i - 1) + 1;
        for j = 1:m
            bar_j = index_nodes_connected(j, :);
            if i == bar_j(1)
                B(B_row_index:B_row_index + 2, j) = -(nodes(:, bar_j(2)) - nodes(:, bar_j(1))) / l(j);
            elseif i == bar_j(2)
                B(B_row_index:B_row_index + 2, j) = (nodes(:, bar_j(2)) - nodes(:, bar_j(1))) / l(j);
            end
        end
    end
    B = sparse(B);
    
    %% Support reaction forces matrix
    n_s = length(index_nodes_fixed);
    I_supp = spalloc(3 * n, 3 * n_s, 3 * n_s);
    for i = 1:n_s
        row = 3 * (index_nodes_fixed(i) - 1) + 1;
        col = 3 * (i - 1) + 1;
        I_supp(row:row + 2, col:col + 2) = speye(3);
    end
    
    %% Prescribed external forces (and matrix)
    %I_ext = spalloc(3 * n, 3 * (n - n_s), 3 * (n - n_s));
    %for i = 1:(n - n_s)
    %    row = 3 * (index_nodes_free(i) - 1) + 1;
    %    col = 3 * (i - 1) + 1;
    %    I_ext(row:row + 2, col:col + 2) = speye(3);
    %end
    %forces_ext = sparse(reshape(forces_ext(:, index_nodes_free), 3 * (n - n_s), 1));
    
    % I_ext * forces_ext gives: (builds directly instead)
    forces_ext = sparse(reshape(forces_ext, 3 * n, 1));
    
end